@@ -12,6 +12,9 @@
 #'
 #' @docType package
 #' @name smmt
+#' 
+#' @keywords internal 
+"_PACKAGE"
 #'
 #' @import XML
 #' @import dplyr
@@ -31,4 +34,4 @@ utils::globalVariables(c("admission_date", "state", "status",
 "municipalityAdmissionNumber", "municipalityDateOfChange",
 "municipalityEntryMode", "municipalityId", "municipalityLongName",
 "municipalityShortName", "municipalityStatus", "name_new", "name_old", 
-"is_xml", "Name", "bfs_nr", "canton", "is_draft", "change_date"))
+"is_xml", "Name", "bfs_nr", "canton", "is_draft", "change_date", "is_proposal", "name", "is_new"))
